@@ -29,6 +29,7 @@ class LebaiHttpService:
         }
         if inner_data is not None:
             data['data'] = inner_data
+        print('yyyy', data)
         r = requests.post(self.get_url("/public/robot/action"), data=json.dumps(data))
         return self.handle_result(r)
 
@@ -65,7 +66,7 @@ class LebaiHttpService:
         r.raise_for_status()
         r = r.json()
         if r['code'] == 0:
-            return r['data']
+            return TaskInfo(r['data'])
         else:
             return None
 
