@@ -59,6 +59,8 @@ class TaskStatus(Enum):
     """停止"""
     ABORTED = 5
     """异常终止"""
+    UNSTARTED = None
+    """未启动"""
 
 
 class IODeviceType(Enum):
